$(document).ready(function(){
	
	//user controller url
	var url = './../controller/trend_analysis_report.php';
	var userId = $('#user_id').data('user-id');
	
	//Annual trends
	$.ajax({
		type: "POST",
		url: url,
		data: {'annual_trend_report_user_id':userId}, 
		success: function(response){
			
			var dataPoint = JSON.parse(response);
			  
			var labels = dataPoint.map(function(e) {
			   return e.year;
			});
			var chartData = dataPoint.map(function(e) {
			   return e.amount;
			});
			
			var annualCtx = $("#annual_linechart");
			var chart = new Chart(annualCtx, {
			  // The type of chart we want to create
			  type: "line",

			  // The data for our dataset
			  data: {
				labels: labels,
				datasets: [
				  {
					label: "",
					backgroundColor: "transparent",
					borderColor: "rgb(82, 136, 255)",
					data: chartData,
					lineTension: 0.3,
					pointRadius: 5,
					pointBackgroundColor: "rgba(255,255,255,1)",
					pointHoverBackgroundColor: "rgba(255,255,255,1)",
					pointBorderWidth: 2,
					pointHoverRadius: 8,
					pointHoverBorderWidth: 1
				  }
				]
			  },

			  // Configuration options go here
			  options: {
				responsive: true,
				maintainAspectRatio: false,
				legend: {
				  display: false
				},
				layout: {
				  padding: {
					right: 10
				  }
				},
				scales: {
				  xAxes: [
					{
					  gridLines: {
						display: false
					  }
					}
				  ],
				  yAxes: [
					{
					  gridLines: {
						display: true,
						color: "#eee",
						zeroLineColor: "#eee",
					  },
					  ticks: {
						callback: function(value) {
						  var ranges = [
							{ divider: 1e6, suffix: "M" },
							{ divider: 1e3, suffix: "k" }
						  ];
						  function formatNumber(n) {
							for (var i = 0; i < ranges.length; i++) {
							  if (n >= ranges[i].divider) {
								return (
								  (n / ranges[i].divider).toString() + ranges[i].suffix
								);
							  }
							}
							return n;
						  }
						  return formatNumber(value);
						}
					  }
					}
				  ]
				},
				tooltips: {
				  callbacks: {
					title: function(tooltipItem, data) {
					  return data["labels"][tooltipItem[0]["index"]];
					},
					label: function(tooltipItem, data) {
					  return "Ugx" + data["datasets"][0]["data"][tooltipItem["index"]];
					}
				  },
				  responsive: true,
				  intersect: false,
				  enabled: true,
				  titleFontColor: "#888",
				  bodyFontColor: "#555",
				  titleFontSize: 12,
				  bodyFontSize: 18,
				  backgroundColor: "rgba(256,256,256,0.95)",
				  xPadding: 20,
				  yPadding: 10,
				  displayColors: false,
				  borderColor: "rgba(220, 220, 220, 0.9)",
				  borderWidth: 2,
				  caretSize: 10,
				  caretPadding: 15
				}
			  }
			});
			
		},
		error: function(){ 
		
			//alert('No patients found'); 
		}
	});
	
	//Annual Department trends
	$.ajax({
		type: "POST",
		url: url,
		data: {'annual_dept_report_user_id':userId}, 
		success: function(response){
			
			var dataPoint = JSON.parse(response);
			  
			var labels = dataPoint.map(function(e) {
			   return e.request_type;
			});
			var chartData = dataPoint.map(function(e) {
			   return e.cost;
			});
			var color = dataPoint.map(function(e) {
			   return e.color;
			});
			
			var annualDoughnut = $("#annual_dept_sales_chart");
			var myDoughnutChart = new Chart(annualDoughnut, {
			  type: "doughnut",
			  data: {
				labels: labels,
				datasets: [
				  {
					label: labels,
					data: chartData,
					backgroundColor: color,
					borderWidth: 1
					// borderColor: ['#4c84ff','#29cc97','#8061ef','#fec402']
					// hoverBorderColor: ['#4c84ff', '#29cc97', '#8061ef', '#fec402']
				  }
				]
			  },
			  options: {
				responsive: true,
				maintainAspectRatio: false,
				legend: {
				  display: true
				},
				cutoutPercentage: 75,
				tooltips: {
				  callbacks: {
					title: function(tooltipItem, data) {
					  return "Department : " + data["labels"][tooltipItem[0]["index"]];
					},
					label: function(tooltipItem, data) {
					  return data["datasets"][0]["data"][tooltipItem["index"]];
					}
				  },
				  titleFontColor: "#888",
				  bodyFontColor: "#555",
				  titleFontSize: 12,
				  bodyFontSize: 14,
				  backgroundColor: "rgba(256,256,256,0.95)",
				  displayColors: true,
				  borderColor: "rgba(220, 220, 220, 0.9)",
				  borderWidth: 2
				}
			  }
			});
			
		},
		error: function(){ 
		
			//alert('No patients found'); 
		}
	});
	
	//Annual Department trends Bar chart
	$.ajax({
		type: "POST",
		url: url,
		data: {'annual_dept_report_user_id':userId}, 
		success: function(response){
			
			var dataPoint = JSON.parse(response);
			  
			var labels = dataPoint.map(function(e) {
			   return e.request_type;
			});
			var chartData = dataPoint.map(function(e) {
			   return e.cost;
			});
			var color = dataPoint.map(function(e) {
			   return e.color;
			});
			
			var annualBar = $("#annual_dept_sales_bar_chart");
			var myUChart = new Chart(annualBar, {
			  type: "bar",
			  data: {
				labels: labels,
				datasets: [
				  {
					label: labels,
					data: chartData,
					backgroundColor: color,
					borderWidth: 2,
					borderRadius: 10,
				  }
				]
			  },
			  options: {
				responsive: true,
				maintainAspectRatio: false,
				legend: {
				  display: false
				},
				scales: {
				  xAxes: [
					{
					  gridLines: {
						drawBorder: true,
						display: false,
					  },
					  ticks: {
						fontColor: "#8a909d",
						fontFamily: "Roboto, sans-serif",
						display: true, // hide main x-axis line
						beginAtZero: true,
						callback: function(tick, index, array) {
						  return index % 1 ? "" : tick;
						}
					  },
					  barPercentage: 1.8,
					  categoryPercentage: 0.2
					}
				  ],
				  yAxes: [
					{
					  gridLines: {
						drawBorder: true,
						display: true,
						color: "#eee",
						zeroLineColor: "#eee"
					  },
					  ticks: {
						fontColor: "#8a909d",
						fontFamily: "Roboto, sans-serif",
						display: true,
						beginAtZero: true
					  }
					}
				  ]
				},

				tooltips: {
				  mode: "index",
				  titleFontColor: "#888",
				  bodyFontColor: "#555",
				  titleFontSize: 12,
				  bodyFontSize: 15,
				  backgroundColor: "rgba(256,256,256,0.95)",
				  displayColors: true,
				  xPadding: 10,
				  yPadding: 7,
				  borderColor: "rgba(220, 220, 220, 0.9)",
				  borderWidth: 2,
				  caretSize: 6,
				  caretPadding: 5
				}
			  }
			});
		},
		error: function(){ 
		
			//alert('No patients found'); 
		}
	});
	
	//Annual age group trends
	$.ajax({
		type: "POST",
		url: url,
		data: {'get_annual_age_group':userId}, 
		success: function(response){

			var dataPoint = JSON.parse(response);
			
			var chartData = dataPoint.map(function(e) {
			   return e.numbers;
			});
			
			var annualAgeGroupPolar = $("#annual_age_group_polar_chart");
			var myPolarChart = new Chart(annualAgeGroupPolar, {
			  type: "polarArea",
			  data: {
				labels: ['Below Ten Yrs','Between Ten & Eighteen Yrs','Above Eighteen Yrs'],
				datasets: [
				  {
					label: ['Below Ten Yrs','Between Ten & Eighteen Yrs','Above Eighteen Yrs'],
					data: chartData,
					backgroundColor: ['#0096FF','#DE3163','#50C878']
				  }
				]
			  },
			  options: {
				responsive: true,
				maintainAspectRatio: false,
				legend: {
				  display: true
				},
				plugins: {
				  legend: {
					position: 'top',
				  },
				  title: {
					display: true,
					text: 'Chart.js Polar Area Chart'
				  }
				}
			  }
			});
			
		},
		error: function(){ 
		
			//alert('No patients found'); 
		}
	});
	
	//Annual pharmacy trends
	$.ajax({
		type: "POST",
		url: url,
		data: {'get_annual_top_pharmacy':userId}, 
		success: function(response){

			var dataPoint = JSON.parse(response);
			
			var labels = dataPoint.map(function(e) {
			   return e.request_name;
			});
			var chartData = dataPoint.map(function(e) {
			   return e.cost;
			});
			
			var annualPharmacyBar = $("#annual_pharmacy_sales_bar_chart");
			var myPharmBarChart = new Chart(annualPharmacyBar, {
			  type: "horizontalBar",
			  data: {
				labels: labels,
				datasets: [
				  {
					label: labels,
					data: chartData,
					backgroundColor: '#4c84ff',
					borderWidth: 1
				  }
				]
			  },
			  options: {
				indexAxis: 'y',
				responsive: true,
				maintainAspectRatio: false,
				legend: {
				  display: false
				},
				scales: {
				  xAxes: [
					{
					  gridLines: {
						drawBorder: true,
						display: true,
					  },
					  ticks: {
						fontColor: "#8a909d",
						fontFamily: "Roboto, sans-serif",
						display: true, // hide main x-axis line
						beginAtZero: true,
						callback: function(tick, index, array) {
						  return tick;
						}
					  },
					  barPercentage: 1.5,
					  categoryPercentage: 0.2
					}
				  ],
				  yAxes: [
					{
					  gridLines: {
						drawBorder: true,
						display: true,
						color: "#eee",
						zeroLineColor: "#eee"
					  },
					  ticks: {
						fontColor: "#8a909d",
						fontFamily: "Roboto, sans-serif",
						display: true,
						beginAtZero: true
					  }
					}
				  ]
				},

				tooltips: {
				  mode: "index",
				  titleFontColor: "#888",
				  bodyFontColor: "#555",
				  titleFontSize: 12,
				  bodyFontSize: 15,
				  backgroundColor: "rgba(256,256,256,0.95)",
				  displayColors: true,
				  xPadding: 10,
				  yPadding: 7,
				  borderColor: "rgba(220, 220, 220, 0.9)",
				  borderWidth: 2,
				  caretSize: 6,
				  caretPadding: 5
				}
			  }
			});
			
		},
		error: function(){ 
		
			//alert('No patients found'); 
		}
	});
	
	//Annual gender trends
	$.ajax({
		type: "POST",
		url: url,
		data: {'get_annual_gender':userId}, 
		success: function(response){

			var dataPoint = JSON.parse(response);
			
			var labels = dataPoint.map(function(e) {
			   return e.gender;
			});
			var chartData = dataPoint.map(function(e) {
			   return e.numbers;
			});
			var color = dataPoint.map(function(e) {
			   return e.color;
			});
			
			var annualGenderPie = $("#annual_gender_pie_chart");
			var myPolarChart = new Chart(annualGenderPie, {
			  type: "pie",
			  data: {
				labels: labels,
				datasets: [
				  {
					label: labels,
					data: chartData,
					backgroundColor: color
				  }
				]
			  },
			  options: {
				responsive: true,
				maintainAspectRatio: false,
				legend: {
				  display: true
				},
				plugins: {
				  legend: {
					position: 'top',
				  },
				  title: {
					display: true,
					text: 'Chart.js Polar Area Chart'
				  }
				}
			  }
			});
			
		},
		error: function(){ 
		
			//alert('No patients found'); 
		}
	});
	
	//Annual Laboratory trends
	$.ajax({
		type: "POST",
		url: url,
		data: {'get_annual_top_laboratory':userId}, 
		success: function(response){

			var dataPoint = JSON.parse(response);
			
			var labels = dataPoint.map(function(e) {
			   return e.test_name;
			});
			var chartData = dataPoint.map(function(e) {
			   return e.total_amount;
			});
			
			var annualLaboratoryBar = $("#annual_lab_sales_bar_chart");
			var myPharmBarChart = new Chart(annualLaboratoryBar, {
			  type: "horizontalBar",
			  data: {
				labels: labels,
				datasets: [
				  {
					label: labels,
					data: chartData,
					fill: true,
					backgroundColor: '#FCAD49',
					borderSkipped: false,
					borderRadius: 20
					
				  }
				]
			  },
			  options: {
				indexAxis: 'y',
				responsive: true,
				maintainAspectRatio: false,
				legend: {
				  display: false
				},
				scales: {
				  xAxes: [
					{
					  gridLines: {
						drawBorder: true,
						display: true,
					  },
					  stacked: true,
					  ticks: {
						fontColor: "#8a909d",
						fontFamily: "Roboto, sans-serif",
						display: true, // hide main x-axis line
						beginAtZero: true,
						callback: function(tick, index, array) {
						  return tick;
						}
					  },
					  barPercentage: 1.5,
					  categoryPercentage: 0.2
					}
				  ],
				  yAxes: [
					{
					  gridLines: {
						drawBorder: true,
						display: true,
						color: "#eee",
						zeroLineColor: "#eee"
					  },
					  ticks: {
						fontColor: "#8a909d",
						fontFamily: "Roboto, sans-serif",
						display: true,
						beginAtZero: true
					  }
					}
				  ]
				},

				tooltips: {
				  mode: "index",
				  titleFontColor: "#888",
				  bodyFontColor: "#555",
				  titleFontSize: 12,
				  bodyFontSize: 15,
				  backgroundColor: "rgba(256,256,256,0.95)",
				  displayColors: true,
				  xPadding: 10,
				  yPadding: 7,
				  borderColor: "rgba(220, 220, 220, 0.9)",
				  borderWidth: 2,
				  caretSize: 6,
				  caretPadding: 5
				}
			  }
			});
			
		},
		error: function(){ 
		
			//alert('No patients found'); 
		}
	});
	
	//Annual Clinical Services trends
	$.ajax({
		type: "POST",
		url: url,
		data: {'get_annual_top_clinical_services':userId}, 
		success: function(response){

			var dataPoint = JSON.parse(response);
			
			var labels = dataPoint.map(function(e) {
			   return e.service_name;
			});
			var chartData = dataPoint.map(function(e) {
			   return e.total_amount;
			});
			
			var annualClinicalBar = $("#annual_clinical_sales_bar_chart");
			var myClinicalBarChart = new Chart(annualClinicalBar, {
			  type: "horizontalBar",
			  data: {
				labels: labels,
				datasets: [
				  {
					label: labels,
					data: chartData,
					fill: true,
					backgroundColor: '#8549FC',
					borderSkipped: false,
					borderRadius: 20
					
				  }
				]
			  },
			  options: {
				indexAxis: 'y',
				responsive: true,
				maintainAspectRatio: false,
				legend: {
				  display: false
				},
				scales: {
				  xAxes: [
					{
					  gridLines: {
						drawBorder: true,
						display: true,
					  },
					  stacked: true,
					  ticks: {
						fontColor: "#8a909d",
						fontFamily: "Roboto, sans-serif",
						display: true, // hide main x-axis line
						beginAtZero: true,
						callback: function(tick, index, array) {
						  return tick;
						}
					  },
					  barPercentage: 1.5,
					  categoryPercentage: 0.2
					}
				  ],
				  yAxes: [
					{
					  gridLines: {
						drawBorder: true,
						display: true,
						color: "#eee",
						zeroLineColor: "#eee"
					  },
					  ticks: {
						fontColor: "#8a909d",
						fontFamily: "Roboto, sans-serif",
						display: true,
						beginAtZero: true
					  }
					}
				  ]
				},

				tooltips: {
				  mode: "index",
				  titleFontColor: "#888",
				  bodyFontColor: "#555",
				  titleFontSize: 12,
				  bodyFontSize: 15,
				  backgroundColor: "rgba(256,256,256,0.95)",
				  displayColors: true,
				  xPadding: 10,
				  yPadding: 7,
				  borderColor: "rgba(220, 220, 220, 0.9)",
				  borderWidth: 2,
				  caretSize: 6,
				  caretPadding: 5
				}
			  }
			});
			
		},
		error: function(){ 
		
			//alert('No patients found'); 
		}
	});
//**********************************************************************Monthly Reports Start Here*************************************************************//	
//*************************************************************************************************************************************************************//

	//Get monthly income report
	$('#monthly_daterange_input').on('apply.daterangepicker', function(ev, picker) {
		var startDate = picker.startDate.format('YYYY-MM-DD');
		var endDate = picker.endDate.format('YYYY-MM-DD');
		
		var startDateHeader = picker.startDate.format('DD-MMM-YYYY');
		var endDateHeader = picker.endDate.format('DD-MMM-YYYY');
		
		$('.monthly_header').html(startDateHeader +' - '+endDateHeader);
		
		//Annual trends
		$.ajax({
			type: "POST",
			url: url,
			data: {'monthly_report_start_date':startDate,'monthly_report_end_date':endDate,'monthly_report_user_id':userId}, 
			success: function(response){
				
				var dataPoint = JSON.parse(response);
				  
				var labels = dataPoint.map(function(e) {
				   return e.month;
				});
				var chartData = dataPoint.map(function(e) {
				   return e.amount;
				});
				
				var ctx2 = $("#monthly_linechart");
				var chart2 = new Chart(ctx2, {
				  // The type of chart we want to create
				  type: "line",

				  // The data for our dataset
				  data: {
					labels: labels,
					datasets: [
					  {
						label: "",
						backgroundColor: "transparent",
						borderColor: "rgb(82, 136, 255)",
						data: chartData,
						lineTension: 0.3,
						pointRadius: 5,
						pointBackgroundColor: "rgba(255,255,255,1)",
						pointHoverBackgroundColor: "rgba(255,255,255,1)",
						pointBorderWidth: 2,
						pointHoverRadius: 8,
						pointHoverBorderWidth: 1
					  }
					]
				  },

				  // Configuration options go here
				  options: {
					responsive: true,
					maintainAspectRatio: false,
					legend: {
					  display: false
					},
					layout: {
					  padding: {
						right: 10
					  }
					},
					scales: {
					  xAxes: [
						{
						  gridLines: {
							display: false
						  }
						}
					  ],
					  yAxes: [
						{
						  gridLines: {
							display: true,
							color: "#eee",
							zeroLineColor: "#eee",
						  },
						  ticks: {
							callback: function(value) {
							  var ranges = [
								{ divider: 1e6, suffix: "M" },
								{ divider: 1e3, suffix: "k" }
							  ];
							  function formatNumber(n) {
								for (var i = 0; i < ranges.length; i++) {
								  if (n >= ranges[i].divider) {
									return (
									  (n / ranges[i].divider).toString() + ranges[i].suffix
									);
								  }
								}
								return n;
							  }
							  return formatNumber(value);
							}
						  }
						}
					  ]
					},
					tooltips: {
					  callbacks: {
						title: function(tooltipItem, data) {
						  return data["labels"][tooltipItem[0]["index"]];
						},
						label: function(tooltipItem, data) {
						  return "Ugx" + data["datasets"][0]["data"][tooltipItem["index"]];
						}
					  },
					  responsive: true,
					  intersect: false,
					  enabled: true,
					  titleFontColor: "#888",
					  bodyFontColor: "#555",
					  titleFontSize: 12,
					  bodyFontSize: 18,
					  backgroundColor: "rgba(256,256,256,0.95)",
					  xPadding: 20,
					  yPadding: 10,
					  displayColors: false,
					  borderColor: "rgba(220, 220, 220, 0.9)",
					  borderWidth: 2,
					  caretSize: 10,
					  caretPadding: 15
					}
				  }
				});
				
			},
			error: function(){ 
			
				//alert('No patients found'); 
			}
		});
		
		//Monthly Department trends
		$.ajax({
			type: "POST",
			url: url,
			data: {'monthly_dept_start_date':startDate,'monthly_dept_end_date':endDate,'monthly_dept_user_id':userId}, 
			success: function(response){
				
				var dataPoint = JSON.parse(response);
				  
				var labels = dataPoint.map(function(e) {
				   return e.request_type;
				});
				var chartData = dataPoint.map(function(e) {
				   return e.cost;
				});
				var color = dataPoint.map(function(e) {
				   return e.color;
				});
				//alert(labels);
				var monthlyDoughnut = $("#monthly_dept_sales_chart");
				var myDoughnutChart2 = new Chart(monthlyDoughnut, {
				  type: "doughnut",
				  data: {
					labels: labels,
					datasets: [
					  {
						label: labels,
						data: chartData,
						backgroundColor: color,
						borderWidth: 1
						// borderColor: ['#4c84ff','#29cc97','#8061ef','#fec402']
						// hoverBorderColor: ['#4c84ff', '#29cc97', '#8061ef', '#fec402']
					  }
					]
				  },
				  options: {
					responsive: true,
					maintainAspectRatio: false,
					legend: {
					  display: true
					},
					cutoutPercentage: 75,
					tooltips: {
					  callbacks: {
						title: function(tooltipItem, data) {
						  return "Department : " + data["labels"][tooltipItem[0]["index"]];
						},
						label: function(tooltipItem, data) {
						  return data["datasets"][0]["data"][tooltipItem["index"]];
						}
					  },
					  titleFontColor: "#888",
					  bodyFontColor: "#555",
					  titleFontSize: 12,
					  bodyFontSize: 14,
					  backgroundColor: "rgba(256,256,256,0.95)",
					  displayColors: true,
					  borderColor: "rgba(220, 220, 220, 0.9)",
					  borderWidth: 2
					}
				  }
				});
				
			},
			error: function(){ 
			
				//alert('No patients found'); 
			}
		});
		
		//Monthly Department trends Bar chart
		$.ajax({
			type: "POST",
			url: url,
			data: {'monthly_bar_start_date':startDate,'monthly_bar_end_date':endDate,'monthly_bar_user_id':userId}, 
			success: function(response){
				
				var dataPoint = JSON.parse(response);
				  
				var labels = dataPoint.map(function(e) {
				   return e.request_type;
				});
				var chartData = dataPoint.map(function(e) {
				   return e.cost;
				});
				var color = dataPoint.map(function(e) {
				   return e.color;
				});
				
				var annualBar2 = $("#monthly_dept_sales_bar_chart");
				var myUChart2 = new Chart(annualBar2, {
				  type: "bar",
				  data: {
					labels: labels,
					datasets: [
					  {
						label: labels,
						data: chartData,
						backgroundColor: color,
						borderWidth: 2,
						borderRadius: 10,
					  }
					]
				  },
				  options: {
					responsive: true,
					maintainAspectRatio: false,
					legend: {
					  display: false
					},
					scales: {
					  xAxes: [
						{
						  gridLines: {
							drawBorder: true,
							display: false,
						  },
						  ticks: {
							fontColor: "#8a909d",
							fontFamily: "Roboto, sans-serif",
							display: true, // hide main x-axis line
							beginAtZero: true,
							callback: function(tick, index, array) {
							  return index % 1 ? "" : tick;
							}
						  },
						  barPercentage: 1.8,
						  categoryPercentage: 0.2
						}
					  ],
					  yAxes: [
						{
						  gridLines: {
							drawBorder: true,
							display: true,
							color: "#eee",
							zeroLineColor: "#eee"
						  },
						  ticks: {
							fontColor: "#8a909d",
							fontFamily: "Roboto, sans-serif",
							display: true,
							beginAtZero: true
						  }
						}
					  ]
					},

					tooltips: {
					  mode: "index",
					  titleFontColor: "#888",
					  bodyFontColor: "#555",
					  titleFontSize: 12,
					  bodyFontSize: 15,
					  backgroundColor: "rgba(256,256,256,0.95)",
					  displayColors: true,
					  xPadding: 10,
					  yPadding: 7,
					  borderColor: "rgba(220, 220, 220, 0.9)",
					  borderWidth: 2,
					  caretSize: 6,
					  caretPadding: 5
					}
				  }
				});
			},
			error: function(){ 
			
				//alert('No patients found'); 
			}
		});
		
		//Monthly age group trends
		$.ajax({
			type: "POST",
			url: url,
			data: {'monthly_age_group_start_date':startDate,'monthly_age_group_end_date':endDate,'monthly_age_group_user_id':userId}, 
			success: function(response){

				var dataPoint = JSON.parse(response);
				
				var chartData = dataPoint.map(function(e) {
				   return e.numbers;
				});
				
				var monthlyAgeGroupPolar = $("#monthly_age_group_polar_chart");
				var myPolarChart2 = new Chart(monthlyAgeGroupPolar, {
				  type: "polarArea",
				  data: {
					labels: ['Below Ten Yrs','Between Ten & Eighteen Yrs','Above Eighteen Yrs'],
					datasets: [
					  {
						label: ['Below Ten Yrs','Between Ten & Eighteen Yrs','Above Eighteen Yrs'],
						data: chartData,
						backgroundColor: ['#0096FF','#DE3163','#50C878']
					  }
					]
				  },
				  options: {
					responsive: true,
					maintainAspectRatio: false,
					legend: {
					  display: true
					},
					plugins: {
					  legend: {
						position: 'top',
					  },
					  title: {
						display: true,
						text: 'Chart.js Polar Area Chart'
					  }
					}
				  }
				});
				
			},
			error: function(){ 
			
				//alert('No patients found'); 
			}
		});
		
		//Annual pharmacy trends
		$.ajax({
			type: "POST",
			url: url,
			data: {'monthly_pharmacy_start_date':startDate,'monthly_pharmacy_end_date':endDate,'get_monthly_top_pharmacy':userId}, 
			success: function(response){

				var dataPoint = JSON.parse(response);
				
				var labels = dataPoint.map(function(e) {
				   return e.request_name;
				});
				var chartData = dataPoint.map(function(e) {
				   return e.cost;
				});
				
				var monthlyPharmacyBar = $("#monthly_pharmacy_sales_bar_chart");
				var myPharmBarChart2 = new Chart(monthlyPharmacyBar, {
				  type: "horizontalBar",
				  data: {
					labels: labels,
					datasets: [
					  {
						label: labels,
						data: chartData,
						backgroundColor: '#4c84ff',
						borderWidth: 1
					  }
					]
				  },
				  options: {
					indexAxis: 'y',
					responsive: true,
					maintainAspectRatio: false,
					legend: {
					  display: false
					},
					scales: {
					  xAxes: [
						{
						  gridLines: {
							drawBorder: true,
							display: true,
						  },
						  ticks: {
							fontColor: "#8a909d",
							fontFamily: "Roboto, sans-serif",
							display: true, // hide main x-axis line
							beginAtZero: true,
							callback: function(tick, index, array) {
							  return tick;
							}
						  },
						  barPercentage: 1.5,
						  categoryPercentage: 0.2
						}
					  ],
					  yAxes: [
						{
						  gridLines: {
							drawBorder: true,
							display: true,
							color: "#eee",
							zeroLineColor: "#eee"
						  },
						  ticks: {
							fontColor: "#8a909d",
							fontFamily: "Roboto, sans-serif",
							display: true,
							beginAtZero: true
						  }
						}
					  ]
					},

					tooltips: {
					  mode: "index",
					  titleFontColor: "#888",
					  bodyFontColor: "#555",
					  titleFontSize: 12,
					  bodyFontSize: 15,
					  backgroundColor: "rgba(256,256,256,0.95)",
					  displayColors: true,
					  xPadding: 10,
					  yPadding: 7,
					  borderColor: "rgba(220, 220, 220, 0.9)",
					  borderWidth: 2,
					  caretSize: 6,
					  caretPadding: 5
					}
				  }
				});
				
			},
			error: function(){ 
			
				//alert('No patients found'); 
			}
		});
		
		//Annual gender trends
		$.ajax({
			type: "POST",
			url: url,
			data: {'monthly_gender_start_date':startDate,'monthly_gender_end_date':endDate,'get_monthly_gender_user_id':userId}, 
			success: function(response){

				var dataPoint = JSON.parse(response);
				
				var labels = dataPoint.map(function(e) {
				   return e.gender;
				});
				var chartData = dataPoint.map(function(e) {
				   return e.numbers;
				});
				var color = dataPoint.map(function(e) {
				   return e.color;
				});
				
				var monthlyGenderPie = $("#monthly_gender_pie_chart");
				var myPolarChart2 = new Chart(monthlyGenderPie, {
				  type: "pie",
				  data: {
					labels: labels,
					datasets: [
					  {
						label: labels,
						data: chartData,
						backgroundColor: color
					  }
					]
				  },
				  options: {
					responsive: true,
					maintainAspectRatio: false,
					legend: {
					  display: true
					},
					plugins: {
					  legend: {
						position: 'top',
					  },
					  title: {
						display: true,
						text: 'Chart.js Polar Area Chart'
					  }
					}
				  }
				});
				
			},
			error: function(){ 
			
				//alert('No patients found'); 
			}
		});
		
		//Annual Laboratory trends
		$.ajax({
			type: "POST",
			url: url,
			data: {'monthly_laboratory_start_date':startDate,'monthly_laboratory_end_date':endDate,'monthly_laboratory_user_id':userId}, 
			success: function(response){

				var dataPoint = JSON.parse(response);
				
				var labels = dataPoint.map(function(e) {
				   return e.test_name;
				});
				var chartData = dataPoint.map(function(e) {
				   return e.total_amount;
				});
				
				var monthlyLaboratoryBar = $("#monthly_lab_sales_bar_chart");
				var myLabBarChart2 = new Chart(monthlyLaboratoryBar, {
				  type: "horizontalBar",
				  data: {
					labels: labels,
					datasets: [
					  {
						label: labels,
						data: chartData,
						fill: true,
						backgroundColor: '#FCAD49',
						borderSkipped: false,
						borderRadius: 20
						
					  }
					]
				  },
				  options: {
					indexAxis: 'y',
					responsive: true,
					maintainAspectRatio: false,
					legend: {
					  display: false
					},
					scales: {
					  xAxes: [
						{
						  gridLines: {
							drawBorder: true,
							display: true,
						  },
						  stacked: true,
						  ticks: {
							fontColor: "#8a909d",
							fontFamily: "Roboto, sans-serif",
							display: true, // hide main x-axis line
							beginAtZero: true,
							callback: function(tick, index, array) {
							  return tick;
							}
						  },
						  barPercentage: 1.5,
						  categoryPercentage: 0.2
						}
					  ],
					  yAxes: [
						{
						  gridLines: {
							drawBorder: true,
							display: true,
							color: "#eee",
							zeroLineColor: "#eee"
						  },
						  ticks: {
							fontColor: "#8a909d",
							fontFamily: "Roboto, sans-serif",
							display: true,
							beginAtZero: true
						  }
						}
					  ]
					},

					tooltips: {
					  mode: "index",
					  titleFontColor: "#888",
					  bodyFontColor: "#555",
					  titleFontSize: 12,
					  bodyFontSize: 15,
					  backgroundColor: "rgba(256,256,256,0.95)",
					  displayColors: true,
					  xPadding: 10,
					  yPadding: 7,
					  borderColor: "rgba(220, 220, 220, 0.9)",
					  borderWidth: 2,
					  caretSize: 6,
					  caretPadding: 5
					}
				  }
				});
				
			},
			error: function(){ 
			
				//alert('No patients found'); 
			}
		});
		
		//Annual Clinical Services trends
		$.ajax({
			type: "POST",
			url: url,
			data: {'monthly_clinical_start_date':startDate,'monthly_clinical_end_date':endDate,'monthly_clinical_user_id':userId}, 
			success: function(response){

				var dataPoint = JSON.parse(response);
				
				var labels = dataPoint.map(function(e) {
				   return e.service_name;
				});
				var chartData = dataPoint.map(function(e) {
				   return e.total_amount;
				});
				
				var monthlyClinicalBar = $("#monthly_clinical_sales_bar_chart");
				var myClinicalBarChart2 = new Chart(monthlyClinicalBar, {
				  type: "horizontalBar",
				  data: {
					labels: labels,
					datasets: [
					  {
						label: labels,
						data: chartData,
						fill: true,
						backgroundColor: '#8549FC',
						borderSkipped: false,
						borderRadius: 20
						
					  }
					]
				  },
				  options: {
					indexAxis: 'y',
					responsive: true,
					maintainAspectRatio: false,
					legend: {
					  display: false
					},
					scales: {
					  xAxes: [
						{
						  gridLines: {
							drawBorder: true,
							display: true,
						  },
						  stacked: true,
						  ticks: {
							fontColor: "#8a909d",
							fontFamily: "Roboto, sans-serif",
							display: true, // hide main x-axis line
							beginAtZero: true,
							callback: function(tick, index, array) {
							  return tick;
							}
						  },
						  barPercentage: 1.5,
						  categoryPercentage: 0.2
						}
					  ],
					  yAxes: [
						{
						  gridLines: {
							drawBorder: true,
							display: true,
							color: "#eee",
							zeroLineColor: "#eee"
						  },
						  ticks: {
							fontColor: "#8a909d",
							fontFamily: "Roboto, sans-serif",
							display: true,
							beginAtZero: true
						  }
						}
					  ]
					},

					tooltips: {
					  mode: "index",
					  titleFontColor: "#888",
					  bodyFontColor: "#555",
					  titleFontSize: 12,
					  bodyFontSize: 15,
					  backgroundColor: "rgba(256,256,256,0.95)",
					  displayColors: true,
					  xPadding: 10,
					  yPadding: 7,
					  borderColor: "rgba(220, 220, 220, 0.9)",
					  borderWidth: 2,
					  caretSize: 6,
					  caretPadding: 5
					}
				  }
				});
				
			},
			error: function(){ 
			
				//alert('No patients found'); 
			}
		});
		
	});
	
//*******************************************************************Daily Reports Start Here*************************************************************//	
//************************************************************************************************************************************************************//

	//Get daily income report
	$('#daily_daterange_input').on('apply.daterangepicker', function(ev, picker) {
		var startDate = picker.startDate.format('YYYY-MM-DD');
		var endDate = picker.endDate.format('YYYY-MM-DD');
		
		var startDateHeader = picker.startDate.format('DD-MMM-YYYY');
		var endDateHeader = picker.endDate.format('DD-MMM-YYYY');
		
		$('.daily_header').html(startDateHeader +' - '+endDateHeader);
		
		//Annual trends
		$.ajax({
			type: "POST",
			url: url,
			data: {'daily_report_start_date':startDate,'daily_report_end_date':endDate,'daily_report_user_id':userId}, 
			success: function(response){
				
				var dataPoint = JSON.parse(response);
				  
				var labels = dataPoint.map(function(e) {
				   return e.month;
				});
				var chartData = dataPoint.map(function(e) {
				   return e.amount;
				});
				
				var ctx3 = $("#daily_linechart");
				var chart3 = new Chart(ctx3, {
				  // The type of chart we want to create
				  type: "line",

				  // The data for our dataset
				  data: {
					labels: labels,
					datasets: [
					  {
						label: "",
						backgroundColor: "transparent",
						borderColor: "rgb(82, 136, 255)",
						data: chartData,
						lineTension: 0.3,
						pointRadius: 5,
						pointBackgroundColor: "rgba(255,255,255,1)",
						pointHoverBackgroundColor: "rgba(255,255,255,1)",
						pointBorderWidth: 2,
						pointHoverRadius: 8,
						pointHoverBorderWidth: 1
					  }
					]
				  },

				  // Configuration options go here
				  options: {
					responsive: true,
					maintainAspectRatio: false,
					legend: {
					  display: false
					},
					layout: {
					  padding: {
						right: 10
					  }
					},
					scales: {
					  xAxes: [
						{
						  gridLines: {
							display: false
						  }
						}
					  ],
					  yAxes: [
						{
						  gridLines: {
							display: true,
							color: "#eee",
							zeroLineColor: "#eee",
						  },
						  ticks: {
							callback: function(value) {
							  var ranges = [
								{ divider: 1e6, suffix: "M" },
								{ divider: 1e3, suffix: "k" }
							  ];
							  function formatNumber(n) {
								for (var i = 0; i < ranges.length; i++) {
								  if (n >= ranges[i].divider) {
									return (
									  (n / ranges[i].divider).toString() + ranges[i].suffix
									);
								  }
								}
								return n;
							  }
							  return formatNumber(value);
							}
						  }
						}
					  ]
					},
					tooltips: {
					  callbacks: {
						title: function(tooltipItem, data) {
						  return data["labels"][tooltipItem[0]["index"]];
						},
						label: function(tooltipItem, data) {
						  return "Ugx" + data["datasets"][0]["data"][tooltipItem["index"]];
						}
					  },
					  responsive: true,
					  intersect: false,
					  enabled: true,
					  titleFontColor: "#888",
					  bodyFontColor: "#555",
					  titleFontSize: 12,
					  bodyFontSize: 18,
					  backgroundColor: "rgba(256,256,256,0.95)",
					  xPadding: 20,
					  yPadding: 10,
					  displayColors: false,
					  borderColor: "rgba(220, 220, 220, 0.9)",
					  borderWidth: 2,
					  caretSize: 10,
					  caretPadding: 15
					}
				  }
				});
				
			},
			error: function(){ 
			
				//alert('No patients found'); 
			}
		});
		
		//Monthly Department trends
		$.ajax({
			type: "POST",
			url: url,
			data: {'daily_dept_start_date':startDate,'daily_dept_end_date':endDate,'daily_dept_user_id':userId}, 
			success: function(response){
				
				var dataPoint = JSON.parse(response);
				  
				var labels = dataPoint.map(function(e) {
				   return e.request_type;
				});
				var chartData = dataPoint.map(function(e) {
				   return e.cost;
				});
				var color = dataPoint.map(function(e) {
				   return e.color;
				});
				//alert(labels);
				var dailyDoughnut = $("#daily_dept_sales_chart");
				var myDoughnutChart3 = new Chart(dailyDoughnut, {
				  type: "doughnut",
				  data: {
					labels: labels,
					datasets: [
					  {
						label: labels,
						data: chartData,
						backgroundColor: color,
						borderWidth: 1
						// borderColor: ['#4c84ff','#29cc97','#8061ef','#fec402']
						// hoverBorderColor: ['#4c84ff', '#29cc97', '#8061ef', '#fec402']
					  }
					]
				  },
				  options: {
					responsive: true,
					maintainAspectRatio: false,
					legend: {
					  display: true
					},
					cutoutPercentage: 75,
					tooltips: {
					  callbacks: {
						title: function(tooltipItem, data) {
						  return "Department : " + data["labels"][tooltipItem[0]["index"]];
						},
						label: function(tooltipItem, data) {
						  return data["datasets"][0]["data"][tooltipItem["index"]];
						}
					  },
					  titleFontColor: "#888",
					  bodyFontColor: "#555",
					  titleFontSize: 12,
					  bodyFontSize: 14,
					  backgroundColor: "rgba(256,256,256,0.95)",
					  displayColors: true,
					  borderColor: "rgba(220, 220, 220, 0.9)",
					  borderWidth: 2
					}
				  }
				});
				
			},
			error: function(){ 
			
				//alert('No patients found'); 
			}
		});
		
		//Monthly Department trends Bar chart
		$.ajax({
			type: "POST",
			url: url,
			data: {'daily_bar_start_date':startDate,'daily_bar_end_date':endDate,'daily_bar_user_id':userId}, 
			success: function(response){
				
				var dataPoint = JSON.parse(response);
				  
				var labels = dataPoint.map(function(e) {
				   return e.request_type;
				});
				var chartData = dataPoint.map(function(e) {
				   return e.cost;
				});
				var color = dataPoint.map(function(e) {
				   return e.color;
				});
				
				var annualBar3 = $("#daily_dept_sales_bar_chart");
				var myUChart3 = new Chart(annualBar3, {
				  type: "bar",
				  data: {
					labels: labels,
					datasets: [
					  {
						label: labels,
						data: chartData,
						backgroundColor: color,
						borderWidth: 2,
						borderRadius: 10,
					  }
					]
				  },
				  options: {
					responsive: true,
					maintainAspectRatio: false,
					legend: {
					  display: false
					},
					scales: {
					  xAxes: [
						{
						  gridLines: {
							drawBorder: true,
							display: false,
						  },
						  ticks: {
							fontColor: "#8a909d",
							fontFamily: "Roboto, sans-serif",
							display: true, // hide main x-axis line
							beginAtZero: true,
							callback: function(tick, index, array) {
							  return index % 1 ? "" : tick;
							}
						  },
						  barPercentage: 1.8,
						  categoryPercentage: 0.2
						}
					  ],
					  yAxes: [
						{
						  gridLines: {
							drawBorder: true,
							display: true,
							color: "#eee",
							zeroLineColor: "#eee"
						  },
						  ticks: {
							fontColor: "#8a909d",
							fontFamily: "Roboto, sans-serif",
							display: true,
							beginAtZero: true
						  }
						}
					  ]
					},

					tooltips: {
					  mode: "index",
					  titleFontColor: "#888",
					  bodyFontColor: "#555",
					  titleFontSize: 12,
					  bodyFontSize: 15,
					  backgroundColor: "rgba(256,256,256,0.95)",
					  displayColors: true,
					  xPadding: 10,
					  yPadding: 7,
					  borderColor: "rgba(220, 220, 220, 0.9)",
					  borderWidth: 2,
					  caretSize: 6,
					  caretPadding: 5
					}
				  }
				});
			},
			error: function(){ 
			
				//alert('No patients found'); 
			}
		});
		
		//Monthly age group trends
		$.ajax({
			type: "POST",
			url: url,
			data: {'daily_age_group_start_date':startDate,'daily_age_group_end_date':endDate,'daily_age_group_user_id':userId}, 
			success: function(response){

				var dataPoint = JSON.parse(response);
				
				var chartData = dataPoint.map(function(e) {
				   return e.numbers;
				});
				
				var dailyAgeGroupPolar = $("#daily_age_group_polar_chart");
				var myPolarChart3 = new Chart(dailyAgeGroupPolar, {
				  type: "polarArea",
				  data: {
					labels: ['Below Ten Yrs','Between Ten & Eighteen Yrs','Above Eighteen Yrs'],
					datasets: [
					  {
						label: ['Below Ten Yrs','Between Ten & Eighteen Yrs','Above Eighteen Yrs'],
						data: chartData,
						backgroundColor: ['#0096FF','#DE3163','#50C878']
					  }
					]
				  },
				  options: {
					responsive: true,
					maintainAspectRatio: false,
					legend: {
					  display: true
					},
					plugins: {
					  legend: {
						position: 'top',
					  },
					  title: {
						display: true,
						text: 'Chart.js Polar Area Chart'
					  }
					}
				  }
				});
				
			},
			error: function(){ 
			
				//alert('No patients found'); 
			}
		});
		
		//Annual pharmacy trends
		$.ajax({
			type: "POST",
			url: url,
			data: {'daily_pharmacy_start_date':startDate,'daily_pharmacy_end_date':endDate,'get_daily_top_pharmacy':userId}, 
			success: function(response){

				var dataPoint = JSON.parse(response);
				
				var labels = dataPoint.map(function(e) {
				   return e.request_name;
				});
				var chartData = dataPoint.map(function(e) {
				   return e.cost;
				});
				
				var dailyPharmacyBar = $("#daily_pharmacy_sales_bar_chart");
				var myPharmBarChart3 = new Chart(dailyPharmacyBar, {
				  type: "horizontalBar",
				  data: {
					labels: labels,
					datasets: [
					  {
						label: labels,
						data: chartData,
						backgroundColor: '#4c84ff',
						borderWidth: 1
					  }
					]
				  },
				  options: {
					indexAxis: 'y',
					responsive: true,
					maintainAspectRatio: false,
					legend: {
					  display: false
					},
					scales: {
					  xAxes: [
						{
						  gridLines: {
							drawBorder: true,
							display: true,
						  },
						  ticks: {
							fontColor: "#8a909d",
							fontFamily: "Roboto, sans-serif",
							display: true, // hide main x-axis line
							beginAtZero: true,
							callback: function(tick, index, array) {
							  return tick;
							}
						  },
						  barPercentage: 1.5,
						  categoryPercentage: 0.2
						}
					  ],
					  yAxes: [
						{
						  gridLines: {
							drawBorder: true,
							display: true,
							color: "#eee",
							zeroLineColor: "#eee"
						  },
						  ticks: {
							fontColor: "#8a909d",
							fontFamily: "Roboto, sans-serif",
							display: true,
							beginAtZero: true
						  }
						}
					  ]
					},

					tooltips: {
					  mode: "index",
					  titleFontColor: "#888",
					  bodyFontColor: "#555",
					  titleFontSize: 12,
					  bodyFontSize: 15,
					  backgroundColor: "rgba(256,256,256,0.95)",
					  displayColors: true,
					  xPadding: 10,
					  yPadding: 7,
					  borderColor: "rgba(220, 220, 220, 0.9)",
					  borderWidth: 2,
					  caretSize: 6,
					  caretPadding: 5
					}
				  }
				});
				
			},
			error: function(){ 
			
				//alert('No patients found'); 
			}
		});
		
		//Annual gender trends
		$.ajax({
			type: "POST",
			url: url,
			data: {'daily_gender_start_date':startDate,'daily_gender_end_date':endDate,'get_daily_gender_user_id':userId}, 
			success: function(response){

				var dataPoint = JSON.parse(response);
				
				var labels = dataPoint.map(function(e) {
				   return e.gender;
				});
				var chartData = dataPoint.map(function(e) {
				   return e.numbers;
				});
				var color = dataPoint.map(function(e) {
				   return e.color;
				});
				
				var dailyGenderPie = $("#daily_gender_pie_chart");
				var myPolarChart3 = new Chart(dailyGenderPie, {
				  type: "pie",
				  data: {
					labels: labels,
					datasets: [
					  {
						label: labels,
						data: chartData,
						backgroundColor: color
					  }
					]
				  },
				  options: {
					responsive: true,
					maintainAspectRatio: false,
					legend: {
					  display: true
					},
					plugins: {
					  legend: {
						position: 'top',
					  },
					  title: {
						display: true,
						text: 'Chart.js Polar Area Chart'
					  }
					}
				  }
				});
				
			},
			error: function(){ 
			
				//alert('No patients found'); 
			}
		});
		
		//Annual Laboratory trends
		$.ajax({
			type: "POST",
			url: url,
			data: {'daily_laboratory_start_date':startDate,'daily_laboratory_end_date':endDate,'daily_laboratory_user_id':userId}, 
			success: function(response){

				var dataPoint = JSON.parse(response);
				
				var labels = dataPoint.map(function(e) {
				   return e.test_name;
				});
				var chartData = dataPoint.map(function(e) {
				   return e.total_amount;
				});
				
				var dailyLaboratoryBar = $("#daily_lab_sales_bar_chart");
				var myLabBarChart3 = new Chart(dailyLaboratoryBar, {
				  type: "horizontalBar",
				  data: {
					labels: labels,
					datasets: [
					  {
						label: labels,
						data: chartData,
						fill: true,
						backgroundColor: '#FCAD49',
						borderSkipped: false,
						borderRadius: 20
						
					  }
					]
				  },
				  options: {
					indexAxis: 'y',
					responsive: true,
					maintainAspectRatio: false,
					legend: {
					  display: false
					},
					scales: {
					  xAxes: [
						{
						  gridLines: {
							drawBorder: true,
							display: true,
						  },
						  stacked: true,
						  ticks: {
							fontColor: "#8a909d",
							fontFamily: "Roboto, sans-serif",
							display: true, // hide main x-axis line
							beginAtZero: true,
							callback: function(tick, index, array) {
							  return tick;
							}
						  },
						  barPercentage: 1.5,
						  categoryPercentage: 0.2
						}
					  ],
					  yAxes: [
						{
						  gridLines: {
							drawBorder: true,
							display: true,
							color: "#eee",
							zeroLineColor: "#eee"
						  },
						  ticks: {
							fontColor: "#8a909d",
							fontFamily: "Roboto, sans-serif",
							display: true,
							beginAtZero: true
						  }
						}
					  ]
					},

					tooltips: {
					  mode: "index",
					  titleFontColor: "#888",
					  bodyFontColor: "#555",
					  titleFontSize: 12,
					  bodyFontSize: 15,
					  backgroundColor: "rgba(256,256,256,0.95)",
					  displayColors: true,
					  xPadding: 10,
					  yPadding: 7,
					  borderColor: "rgba(220, 220, 220, 0.9)",
					  borderWidth: 2,
					  caretSize: 6,
					  caretPadding: 5
					}
				  }
				});
				
			},
			error: function(){ 
			
				//alert('No patients found'); 
			}
		});
		
		//Annual Clinical Services trends
		$.ajax({
			type: "POST",
			url: url,
			data: {'daily_clinical_start_date':startDate,'daily_clinical_end_date':endDate,'daily_clinical_user_id':userId}, 
			success: function(response){

				var dataPoint = JSON.parse(response);
				
				var labels = dataPoint.map(function(e) {
				   return e.service_name;
				});
				var chartData = dataPoint.map(function(e) {
				   return e.total_amount;
				});
				
				var dailyClinicalBar = $("#daily_clinical_sales_bar_chart");
				var myClinicalBarChart3 = new Chart(dailyClinicalBar, {
				  type: "horizontalBar",
				  data: {
					labels: labels,
					datasets: [
					  {
						label: labels,
						data: chartData,
						fill: true,
						backgroundColor: '#8549FC',
						borderSkipped: false,
						borderRadius: 20
						
					  }
					]
				  },
				  options: {
					indexAxis: 'y',
					responsive: true,
					maintainAspectRatio: false,
					legend: {
					  display: false
					},
					scales: {
					  xAxes: [
						{
						  gridLines: {
							drawBorder: true,
							display: true,
						  },
						  stacked: true,
						  ticks: {
							fontColor: "#8a909d",
							fontFamily: "Roboto, sans-serif",
							display: true, // hide main x-axis line
							beginAtZero: true,
							callback: function(tick, index, array) {
							  return tick;
							}
						  },
						  barPercentage: 1.5,
						  categoryPercentage: 0.2
						}
					  ],
					  yAxes: [
						{
						  gridLines: {
							drawBorder: true,
							display: true,
							color: "#eee",
							zeroLineColor: "#eee"
						  },
						  ticks: {
							fontColor: "#8a909d",
							fontFamily: "Roboto, sans-serif",
							display: true,
							beginAtZero: true
						  }
						}
					  ]
					},

					tooltips: {
					  mode: "index",
					  titleFontColor: "#888",
					  bodyFontColor: "#555",
					  titleFontSize: 12,
					  bodyFontSize: 15,
					  backgroundColor: "rgba(256,256,256,0.95)",
					  displayColors: true,
					  xPadding: 10,
					  yPadding: 7,
					  borderColor: "rgba(220, 220, 220, 0.9)",
					  borderWidth: 2,
					  caretSize: 6,
					  caretPadding: 5
					}
				  }
				});
				
			},
			error: function(){ 
			
				//alert('No patients found'); 
			}
		});
		
	});

	
	//Print income report
	$('.print_patient_report').click(function(){
		var mode = 'iframe';
		var Close=mode=='popup';
		var standards = "html5";
		var options = {mode:mode,popClose:Close,standard:standards};
		$('#patient_table').printArea(options);
	});
	
	//Logout
	$('#logout_btn').on('click', function(){
		 
		 alert('You have logged out');
		  var userId = $(this).data('user-id');
		  $.ajax({
			   type: "POST",
			   url: url,
			   data: {'logout_staff_id':userId}, 
			   success: function(data)
			   {
				   //alert(data);
				   window.location.href="./../index.php";
				   
			   },
				error: function() 
				{ 
					alert('There was an error finding the clicked user'); 
				}
			 });
	 });
	
	//Notification
	setInterval(function(){
		
		//Count notifications
		$.ajax({
		   type: "POST",
		   url: url,
		   data: {'count_notifications':userId}, 
		   success: function(data)
		   {
			   $('#notification_bell').html(data);
		   },
			error: function() 
			{ 
				//alert('No patients found'); 
			}
		});
		
		//Get notifications
		$.ajax({
		   type: "POST",
		   url: url,
		   data: {'get_notifications':userId}, 
		   success: function(data)
		   {
			   $('#notification_ul').html(data);
		   },
			error: function() 
			{ 
				//alert('No patients found'); 
			}
		});
		
		
	},5000);
	
	//Read notifications
	$('#notification_bell_div').on('click', function(){
		
		$.ajax({
		   type: "POST",
		   url: url,
		   data: {'read_notifications':userId}, 
		   success: function(data)
		   {
			   //alert(data)
		   },
			error: function() 
			{ 
				//alert('No notifications found'); 
			}
		});
		
	});
	
	
	
});